@@ -19,19 +19,27 @@ from DEWPython import DEWEquations
 from matplotlib.lines import Line2D
 get_ipython().run_line_magic('matplotlib', 'inline')
 from collections import defaultdict
+import pkg_resources
 import os.path as op
 
 # ### Defining a Global Variables (Location and Constants)
-
-# In[3]:
-mineralPath = op.dirname(op.abspath(__file__)) + '\\resources\\mineralDictionary.txt'
-gasPath = op.dirname(op.abspath(__file__)) + '\\resources\\gasLst.txt'
-aqPath = op.dirname(op.abspath(__file__)) + '\\resources\\aqueousLst.txt'
-diePath =  op.dirname(op.abspath(__file__)) + '\\resources\\dielectric.csv'
-inpPath =  op.dirname(op.abspath(__file__)) + '\\resources\\input.csv'
-denPath =  op.dirname(op.abspath(__file__)) + '\\resources\\Wat_den.csv'
-gPath =  op.dirname(op.abspath(__file__)) + '\\resources\\water_gibbs.csv'
-supPath =  op.dirname(op.abspath(__file__)) + '\\resources\\SUPCRTBL.exe'
+resource_package = 'DEWPython'
+min_path = '/'.join(('resources', 'mineralDictionary.txt'))
+mineralPath = pkg_resources.resource_filename(resource_package, min_path)
+gas_path = '/'.join(('resources', 'gasLst.txt'))
+gasPath = pkg_resources.resource_filename(resource_package, gas_path)
+aq_path = '/'.join(('resources', 'aqueousLst.txt'))
+aqPath = pkg_resources.resource_filename(resource_package, aq_path)
+die_path =  '/'.join(('resources', 'dielectric.csv'))
+diePath = pkg_resources.resource_filename(resource_package, die_path)
+inp_path ='/'.join(('resources', 'input.csv'))
+inpPath = pkg_resources.resource_filename(resource_package, inp_path)
+den_path ='/'.join(('resources', 'input.csv'))
+denPath = pkg_resources.resource_filename(resource_package, den_path)
+g_path = '/'.join(('resources', 'water_gibbs.csv'))
+gPath = pkg_resources.resource_filename(resource_package, g_path)
+sup_path = '/'.join(('resources', 'SUPCRTBL.exe'))
+supPath =  pkg_resources.resource_filename(resource_package, sup_path)
 
 global Tr, bigQ, Chi, Pr, E_PrTr, bigR, Psi, Theta, Upsilon, Conversion, mineralDictionary
 
@@ -112,6 +120,15 @@ Conversion = 41.8393
 # # An Object Class that Can Calculate and Return Parameters for Different Options of the Deep Earth Water Model
 
 # In[8]:
+def aqueous_options():
+    for item in nameLst:
+        print(item)
+def gas_options():
+    for item in GasLst:
+        print(item)
+def mineral_options():
+    for key in mineralDictionary:
+        print(key)
 
 
 class DEW(object):
@@ -743,7 +760,7 @@ class DEW(object):
                 else:
                     self.RhoWatArr.append(0)
             else:
-                self.RhoWatArr.append(DEWEquations.calculateDensity(self.pressureUsed[i], self.tempUsed[i], self.equation, 0.01, self.psat))
+                self.RhoWatArr.append(DEWEquations.DEWEquations.calculateDensity(self.pressureUsed[i], self.tempUsed[i], self.equation, 0.01, self.psat))
                
         # Sets the dielectric constant array
         for i in range(len(self.pressureUsed)):
@@ -757,9 +774,9 @@ class DEW(object):
                     self.DiaArr.append(0)
             else:
                 if self.ForceSupcrt == True and self.pressureUsed[i] < 5000 and self.psat == False:
-                    self.DiaArr.append(DEWEquations.calculateEpsilon(self.RhoWatArr[i], self.tempUsed[i], 1, self.psat))
+                    self.DiaArr.append(DEWEquations.DEWEquations.calculateEpsilon(self.RhoWatArr[i], self.tempUsed[i], 1, self.psat))
                 else:
-                    self.DiaArr.append(DEWEquations.calculateEpsilon(self.RhoWatArr[i], self.tempUsed[i], self.diaEq, self.psat))
+                    self.DiaArr.append(DEWEquations.DEWEquations.calculateEpsilon(self.RhoWatArr[i], self.tempUsed[i], self.diaEq, self.psat))
         
         
         ### The function works up until this point, I haven't debugged further yet (6_29_20) ###
@@ -769,7 +786,7 @@ class DEW(object):
             if self.DisplayVol == True:
                 try:
                     # Has issues with some Q, not sure if problematic
-                    self.QArr.append(float(DEWEquations.calculateQ(self.pressureUsed[i], self.tempUsed[i], self.RhoWatArr[i], self.equation, self.diaEq, self.psat))*np.double(10)**6)
+                    self.QArr.append(float(DEWEquations.DEWEquations.calculateQ(self.pressureUsed[i], self.tempUsed[i], self.RhoWatArr[i], self.equation, self.diaEq, self.psat))*np.double(10)**6)
                 except:
                     self.QArr.append(0)
             else:
@@ -933,7 +950,7 @@ class DEW(object):
                     except:
                         waterLst.append(GibbsH2O[i])
                 else:
-                    waterLst.append(DEWEquations.calculateGibbsOfWater(self.pressureUsed[i], self.tempUsed[i], self.myWatNumber, self.equation, self.psat))
+                    waterLst.append(DEWEquations.DEWEquations.calculateGibbsOfWater(self.pressureUsed[i], self.tempUsed[i], self.myWatNumber, self.equation, self.psat))
                 if self.DisplayVol == True:
                     try:
                         waterLst2.append(18.01528/self.RhoWatArr[i])
@@ -978,15 +995,15 @@ class DEW(object):
                                 + aq[8]*(10**2)*np.log((Psy+self.pressureUsed[i])/(Psy+Pr))
                                 + (1/(self.tKelvin[i]-Theta))*(aq[9]*(self.pressureUsed[i]-Pr)
                                                                + aq[10]*(10**4)*np.log((Psy+self.pressureUsed[i])/(Psy+Pr)))
-                                + DEWEquations.calculateOmega(self.pressureUsed[i],self.tempUsed[i],self.RhoWatArr[i],aq[0],aq[13]*(10**5),aq[14])*((1/self.DiaArr[i])-1)
+                                + DEWEquations.DEWEquations.calculateOmega(self.pressureUsed[i],self.tempUsed[i],self.RhoWatArr[i],aq[0],aq[13]*(10**5),aq[14])*((1/self.DiaArr[i])-1)
                                 - aq[13]*(10**5)*((1/E_PrTr)-1)
                                 + aq[13]*(10**5)*Upsilon*(self.tKelvin[i]-T_r))
                 
             for i in range(len(self.pressureUsed)):
                 storelst2.append((aq[7]/10 + aq[8]*100/(Psy+self.pressureUsed[i])
                                   + (aq[9] + aq[10]*10000/(Psy+self.pressureUsed[i]))/(self.tKelvin[i]-Theta)
-                                  - DEWEquations.calculateOmega(self.pressureUsed[i],self.tempUsed[i],self.RhoWatArr[i],aq[0],aq[13]*(10**5),aq[14])*(self.QArr[i]*10**-6 )
-                                  + (1/self.DiaArr[i] - 1) * DEWEquations.calculate_domegadP(self.pressureUsed[i],self.tempUsed[i],self.RhoWatArr[i],aq[0],aq[13]*(10**5),aq[14],self.equation,self.psat))*41.84)
+                                  - DEWEquations.DEWEquations.calculateOmega(self.pressureUsed[i],self.tempUsed[i],self.RhoWatArr[i],aq[0],aq[13]*(10**5),aq[14])*(self.QArr[i]*10**-6 )
+                                  + (1/self.DiaArr[i] - 1) * DEWEquations.DEWEquations.calculate_domegadP(self.pressureUsed[i],self.tempUsed[i],self.RhoWatArr[i],aq[0],aq[13]*(10**5),aq[14],self.equation,self.psat))*41.84)
                 
             aqInGibbs.append(storelst)
             aqInV.append(storelst2)
@@ -1006,15 +1023,15 @@ class DEW(object):
                                 + aq[8]*(10**2)*np.log((Psy+self.pressureUsed[i])/(Psy+Pr))
                                 + (1/(self.tKelvin[i]-Theta))*(aq[9]*(self.pressureUsed[i]-Pr)
                                                                + aq[10]*(10**4)*np.log((Psy+self.pressureUsed[i])/(Psy+Pr)))
-                                + DEWEquations.calculateOmega(self.pressureUsed[i],self.tempUsed[i],self.RhoWatArr[i],aq[0],aq[13]*(10**5),aq[14])*((1/self.DiaArr[i])-1)
+                                + DEWEquations.DEWEquations.calculateOmega(self.pressureUsed[i],self.tempUsed[i],self.RhoWatArr[i],aq[0],aq[13]*(10**5),aq[14])*((1/self.DiaArr[i])-1)
                                 - aq[13]*(10**5)*((1/E_PrTr)-1)
                                 + aq[13]*(10**5)*Upsilon*(self.tKelvin[i]-T_r))
                 
             for i in range(len(self.pressureUsed)):
                 storelst2.append((aq[7]/10 + aq[8]*100/(Psy+self.pressureUsed[i])
                                   + (aq[9] + aq[10]*10000/(Psy+self.pressureUsed[i]))/(self.tKelvin[i]-Theta)
-                                  - DEWEquations.calculateOmega(self.pressureUsed[i],self.tempUsed[i],self.RhoWatArr[i],aq[0],aq[13]*(10**5),aq[14])*(self.QArr[i]*10**-6 )
-                                  + (1/self.DiaArr[i] - 1) * DEWEquations.calculate_domegadP(self.pressureUsed[i],self.tempUsed[i],self.RhoWatArr[i],aq[0],aq[13]*(10**5),aq[14],self.equation,self.psat))*41.84)
+                                  - DEWEquations.DEWEquations.calculateOmega(self.pressureUsed[i],self.tempUsed[i],self.RhoWatArr[i],aq[0],aq[13]*(10**5),aq[14])*(self.QArr[i]*10**-6 )
+                                  + (1/self.DiaArr[i] - 1) * DEWEquations.DEWEquations.calculate_domegadP(self.pressureUsed[i],self.tempUsed[i],self.RhoWatArr[i],aq[0],aq[13]*(10**5),aq[14],self.equation,self.psat))*41.84)
             aqOuGibbs.append(storelst)
             aqOuV.append(storelst2)
         if len(aqInGibbs) == 0:
@@ -1286,7 +1303,31 @@ class DEW(object):
             plt.ylabel('DelV')
             plt.title('Temp vs. DelV Psat Curve')
         return
-    
+       
+    def export_to_csv(self):
+        dV = [row[0] for row in self.delV]
+        dG = [row[0] for row in self.delG]
+        lK = [row[0] for row in self.logK]
+        T = [row[1] for row in self.logK]
+        P = [row[1] for row in self.logK]
+        output_array = np.column_stack([T,P, dV,dG,lK])
+        df = pd.DataFrame(output_array)
+        df.columns = ['Temperature','Pressure','delV','delG','LogK']
+        name = input('Input the name of the CSV file')
+        finalName = name + ".csv"
+        df.to_csv(finalName, index = False)
+        
+    def options(self):
+        print('Welcome to DEWPython, here are the options you can run:')
+        print('1. DEW(): this initializes a Deep Earth Water Model Object')
+        print('  -The DEW object requires the set_inputs, set_outputs, set_TPRho, and calculate methods to be run.')
+        print('  -You can also utilize the import_custom_sheets method to import custom CSV data')
+        print('  -After calculating you can use the make_plots or export_to_csv methods.')
+        print('2. run_supcrt: this initializes an inline run of SUPCRTBL')
+        print('  -After initializing the SUPCRTBL object, run calculate_supcrt to store the supcrt outputs in arrays')
+        print('  -You can also use run_supcrt on a supcrt ouput file that has already been run by adding the optional argument of the file name')
+        print('  -After this you can run make_supcrt_plots to plot the supcrt files akin the a DEW file')
+        
     def outLoop(self):
         '''A helper function to allow SUPCRTBL to run'''
         running = True
